@@ -43,27 +43,24 @@ from sphinx_toolbox import (
 		rest_example,
 		shields,
 		source,
+		utils,
 		wikipedia
 		)
 from sphinx_toolbox.cache import cache
 
-if typing.TYPE_CHECKING:
-	# this package
-	from sphinx_toolbox.utils import SphinxExtMetadata
-
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 
 __license__: str = "MIT License"
-__version__: str = "1.0.0"
+__version__: str = "1.1.0"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["setup"]
 
 
-def setup(app: Sphinx) -> "SphinxExtMetadata":
+def setup(app: Sphinx) -> "utils.SphinxExtMetadata":
 	"""
-	Setup Sphinx Extension.
+	Setup :mod:`sphinx_toolbox`.
 
 	:param app: The Sphinx app.
 	"""
