@@ -45,8 +45,23 @@ The changes are:
   The ``75`` is the priority of the hook. ``< 20`` runs before ``fget`` functions are extracted from properties,
   and ``< 100`` runs before ``__init__`` functions are extracted from classes.
 
+
+-----
+
 .. extensions:: sphinx_toolbox.more_autodoc.typehints
 
+
+For configuration information see https://github.com/agronholm/sphinx-autodoc-typehints
+
+In addition the following configuration value is added by this extension:
+
+.. confval:: hide_none_rtype
+	:type: :class:`bool`
+	:default: :py:obj:`False`
+
+	Hides return types of :py:obj:`None`.
+
+
 .. versionadded:: 0.4.0
 
 .. versionchanged:: 0.6.0
@@ -88,7 +103,13 @@ import operator
 import sys
 import types
 from types import FunctionType, ModuleType
-from typing import Any, AnyStr, Callable, Dict, List, Optional, Tuple, TypeVar
+from typing import Any, AnyStr, Callable, Dict, List, Optional, Tuple, TypeVar, get_type_hints
+
+if sys.version_info[:2] == (3, 6):
+	# stdlib
+	from typing import _ForwardRef as ForwardRef  # type: ignore
+else:
+	from typing import ForwardRef
 
 # 3rd party
 import sphinx_autodoc_typehints  # type: ignore
@@ -117,30 +138,28 @@ except ImportError:  # pragma: no cover
 	pass
 
 __all__ = [
-		"Module",
-		"get_annotation_module",
-		"get_annotation_class_name",
-		"get_annotation_args",
-		"format_annotation",
-		"process_signature",
-		"get_all_type_hints",
-		"backfill_type_hints",
-		"load_args",
-		"split_type_comment_args",
-		"process_docstring",
-		"builder_ready",
-		"docstring_hooks",
-		"setup",
 		"ObjectAlias",
 		"Module",
 		"Function",
 		"Class",
+		"process_signature",
+		"process_docstring",
+		"format_annotation",
+		"docstring_hooks",
+		"setup",
+		"get_annotation_module",
+		"get_annotation_class_name",
+		"get_annotation_args",
+		"get_all_type_hints",
+		"backfill_type_hints",
+		"load_args",
+		"split_type_comment_args",
+		"builder_ready",
 		]
 
 get_annotation_module = sphinx_autodoc_typehints.get_annotation_module
 get_annotation_class_name = sphinx_autodoc_typehints.get_annotation_class_name
 get_annotation_args = sphinx_autodoc_typehints.get_annotation_args
-get_all_type_hints = sphinx_autodoc_typehints.get_all_type_hints
 backfill_type_hints = sphinx_autodoc_typehints.backfill_type_hints
 load_args = sphinx_autodoc_typehints.load_args
 split_type_comment_args = sphinx_autodoc_typehints.split_type_comment_args
@@ -229,33 +248,36 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 		return ":py:obj:`None`"
 	elif annotation is Ellipsis:
 		return "..."
-	elif annotation is types.GetSetDescriptorType:
+	elif annotation is types.GetSetDescriptorType:  # noqa E721
 		return ":py:data:`types.GetSetDescriptorType:`"
-	elif annotation is types.MemberDescriptorType:
+	elif annotation is types.MemberDescriptorType:  # noqa E721
 		return ":py:data:`types.MemberDescriptorType:`"
-	elif annotation is types.MappingProxyType:
+	elif annotation is types.MappingProxyType:  # noqa E721
 		return ":py:data:`types.MappingProxyType:`"
-	elif annotation is types.ModuleType:
+	elif annotation is types.ModuleType:  # noqa E721
 		return ":py:data:`types.ModuleType:`"
-	elif annotation is ClassMethodDescriptorType:
+	elif annotation is ClassMethodDescriptorType:  # noqa E721
 		return ":py:data:`types.ClassMethodDescriptorType:`"
-	elif annotation is MethodDescriptorType:
+	elif annotation is MethodDescriptorType:  # noqa E721
 		return ":py:data:`types.MethodDescriptorType:`"
-	elif annotation is MethodWrapperType:
+	elif annotation is MethodWrapperType:  # noqa E721
 		return ":py:data:`types.MethodWrapperType:`"
-	elif annotation is WrapperDescriptorType:
+	elif annotation is WrapperDescriptorType:  # noqa E721
 		return ":py:data:`types.WrapperDescriptorType:`"
-	elif annotation is types.BuiltinFunctionType:
+	elif annotation is types.BuiltinFunctionType:  # noqa E721
 		return ":py:data:`types.BuiltinFunctionType:`"
-	elif annotation is types.MethodType:
+	elif annotation is types.MethodType:  # noqa E721
 		return ":py:data:`types.MethodType:`"
+	elif isinstance(annotation, ForwardRef):
+		# Unresolved forward ref
+		return f":py:obj:`~.{annotation.__forward_arg__}`"
 
 	try:
 		module = get_annotation_module(annotation)
 		class_name = get_annotation_class_name(annotation, module)
 		args = get_annotation_args(annotation, module, class_name)
 	except ValueError:
-		return str(annotation)
+		return f":py:obj:`~.{annotation}`"
 
 	# Redirect all typing_extensions types to the stdlib typing module
 	if module == "typing_extensions":
@@ -403,6 +425,8 @@ def process_signature(
 	:param signature:
 	:param return_annotation:
 
+	:rtype:
+
 	.. versionchanged:: 0.8.0
 
 		Added support for factory function default values in attrs classes.
@@ -513,6 +537,10 @@ def process_docstring(
 	:param obj: The object being documented.
 	:param options: Mapping of autodoc options to values.
 	:param lines: List of strings representing the current contents of the docstring.
+
+	.. versionchanged:: 1.1.0
+
+		An empty ``:rtype:`` flag can be used to control the position of the return type annotation in the docstring.
 	"""
 
 	original_obj = obj
@@ -522,7 +550,7 @@ def process_docstring(
 
 	if callable(obj):
 		obj = inspect.unwrap(obj)
-		type_hints = get_all_type_hints(obj, name)
+		type_hints = get_all_type_hints(obj, name, original_obj)
 
 		for argname, annotation in type_hints.items():
 			if argname == "return":
@@ -563,19 +591,27 @@ def process_docstring(
 			insert_index = len(lines)
 			for i, line in enumerate(lines):
 				if line.startswith(":rtype:"):
-					insert_index = None
+					if line[7:].strip():
+						insert_index = None
+					else:
+						insert_index = i
+						lines.pop(i)
+
 					break
+
 				elif line.startswith(":return:") or line.startswith(":returns:"):
 					insert_index = i
 
 			if insert_index is not None and app.config.typehints_document_rtype:  # type: ignore
+
 				if insert_index == len(lines):
 					# Ensure that :rtype: doesn't get joined with a paragraph of text, which
 					# prevents it being interpreted.
 					lines.append('')
 					insert_index += 1
 
-				lines.insert(insert_index, f":rtype: {formatted_annotation}")
+				if not (formatted_annotation == ":py:obj:`None`" and app.config.hide_none_rtype):  # type: ignore
+					lines.insert(insert_index, f":rtype: {formatted_annotation}")
 
 
 def setup(app: Sphinx) -> SphinxExtMetadata:
@@ -597,7 +633,95 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	app.setup_extension("sphinx.ext.autodoc")
 	app.setup_extension("sphinx_autodoc_typehints")
 
+	app.add_config_value("hide_none_rtype", False, "env", [bool])
+
 	return {
 			"version": __version__,
 			"parallel_read_safe": True,
 			}
+
+
+def _class_get_type_hints(obj, globalns=None, localns=None):
+	"""
+	Return type hints for an object.
+
+	For classes, unlike :func:`typing.get_type_hints` this will attempt to
+	use the global namespace of the modules where the class and its parents
+	were defined until it can resolve all forward references.
+	"""
+
+	if not inspect.isclass(obj):
+		return get_type_hints(obj, localns=localns, globalns=globalns)
+
+	mro_stack = list(obj.__mro__)
+	if localns is None:
+		localns = {}
+
+	while True:
+
+		try:
+			return get_type_hints(obj.__init__, localns=localns, globalns=globalns)
+		except NameError:
+			if not mro_stack:
+				raise
+			klasse = mro_stack.pop(0)
+			if klasse is object or klasse.__module__ == "builtins":
+				raise
+			localns = {**sys.modules[klasse.__module__].__dict__, **localns}
+
+
+def get_all_type_hints(obj, name, original_obj):
+	"""
+	Returns the resolved type hints for the given objects.
+
+	:param obj:
+	:param name:
+	:param original_obj: The original object, before the class if ``obj`` is its ``__init__`` method.
+
+	:return:
+	"""
+
+	def log(exc):
+		sphinx_autodoc_typehints.logger.warning(
+				'Cannot resolve forward reference in type annotations of "%s": %s',
+				name,
+				exc,
+				)
+
+	rv = {}
+
+	try:
+		if inspect.isclass(original_obj):
+			rv = _class_get_type_hints(original_obj)
+		else:
+			rv = get_type_hints(obj)
+	except (AttributeError, TypeError, RecursionError):
+		# Introspecting a slot wrapper will raise TypeError, and some recursive type
+		# definitions will cause a RecursionError (https://github.com/python/typing/issues/574).
+		pass
+	except NameError as exc:
+		log(exc)
+		rv = obj.__annotations__
+
+	if rv:
+		return rv
+
+	rv = backfill_type_hints(obj, name)
+
+	try:
+		obj.__annotations__ = rv
+	except (AttributeError, TypeError):
+		return rv
+
+	try:
+		if inspect.isclass(original_obj):
+			rv = _class_get_type_hints(original_obj)
+		else:
+			rv = get_type_hints(obj)
+	except (AttributeError, TypeError):
+		pass
+	except NameError as exc:
+		log(exc)
+		rv = obj.__annotations__
+
+	return rv
