@@ -46,6 +46,7 @@ from sphinx.errors import PycodeError
 from sphinx.ext.autodoc import Documenter, logger
 from sphinx.locale import __
 from sphinx.pycode import ModuleAnalyzer
+from typing_extensions import TypedDict
 
 __all__ = [
 		"make_github_url",
@@ -67,12 +68,10 @@ __all__ = [
 		"untyped_param_regex",
 		"typed_flag_regex",
 		"allow_subclass_add",
+		"NoMatchError",
 		]
 
-# 3rd party
 #: Instance of :class:`apeye.url.RequestsURL` that points to the GitHub website.
-from typing_extensions import TypedDict
-
 GITHUB_COM: RequestsURL = RequestsURL("https://github.com")
 
 #: Type hint for the ``option_spec`` variable of Docutils directives.
@@ -127,10 +126,10 @@ class Purger:
 
 	def purge_nodes(self, app: Sphinx, env: BuildEnvironment, docname: str) -> None:
 		"""
-		Remove all redundant :class:`sphinx_toolbox.installation.InstallationDirective` nodes.
+		Remove all redundant nodes.
 
 		:param app: The Sphinx app.
-		:param env:
+		:param env: The Sphinx build environment.
 		:param docname: The name of the document to remove nodes for.
 		"""
 
@@ -146,7 +145,7 @@ class Purger:
 		"""
 		Add a node.
 
-		:param env:
+		:param env: The Sphinx build environment.
 		:param node:
 		:param targetnode:
 		:param lineno:
@@ -165,9 +164,6 @@ class Purger:
 				})
 
 
-_T = TypeVar("_T")
-
-
 def singleton(name: str) -> object:
 	"""
 	Factory function to return a string singleton.
@@ -207,8 +203,11 @@ class NoMatchError(ValueError):
 	"""
 
 
+_T = TypeVar("_T")
+
+
 def get_first_matching(
-		condition: Callable[[_T], bool],
+		condition: Callable[[Any], bool],
 		iterable: Iterable[_T],
 		default: _T = no_default,  # type: ignore
 		) -> _T:
@@ -219,6 +218,8 @@ def get_first_matching(
 	:param iterable:
 	:param default: The default value to return if no values in ``iterable`` match.
 
+	:rtype:
+
 	.. versionadded:: 0.7.0
 	"""
 
@@ -232,7 +233,7 @@ def get_first_matching(
 		if condition(match):
 			return match
 
-	raise NoMatchError(f"No matches values for '{condition}' in {iterable}")
+	raise NoMatchError(f"No matching values for '{condition}' in {iterable}")
 
 
 def escape_trailing__(string: str) -> str:
@@ -241,6 +242,8 @@ def escape_trailing__(string: str) -> str:
 
 	:param string:
 
+	:rtype:
+
 	.. versionadded:: 0.8.0
 	"""
 
@@ -255,6 +258,8 @@ def code_repr(obj: Any) -> str:
 
 	:param obj:
 
+	:rtype:
+
 	.. versionadded:: 0.9.0
 	"""
 
@@ -390,6 +395,8 @@ def unknown_module_warning(documenter: Documenter) -> None:
 
 	:param documenter:
 
+	:rtype:
+
 	.. versionadded:: 0.2.0
 	"""
 
@@ -432,7 +439,7 @@ class Param(TypedDict):
 	doc: List[str]
 
 	#: The type of the parameter.
-	type: str
+	type: str  # noqa A003
 
 
 typed_param_regex: Pattern = re.compile(
@@ -518,10 +525,12 @@ def parse_parameters(lines: List[str], tab_size: int = 8) -> Tuple[Dict[str, Par
 
 def is_namedtuple(obj: Any) -> bool:
 	"""
-	Returns whether the given class is a :class:`collections.namedtuple`.
+	Returns whether the given class is a :func:`collections.namedtuple`.
 
 	:param obj:
 
+	:rtype:
+
 	.. versionadded:: 0.8.0
 	"""
 
@@ -538,8 +547,10 @@ def allow_subclass_add(app: Sphinx, *documenters: Type[Documenter]):
 	:param app: The Sphinx app.
 	:param documenters:
 
+	:rtype:
+
 	.. versionadded:: 0.8.0
-	"""
+	"""  # noqa D400
 
 	for cls in documenters:
 		existing_documenter = app.registry.documenters.get(cls.objtype)
